'use strict';

import Keycloak from './keycloak-js';


class Secured {
    constructor() {
        this.keycloak = null;
        this.authenticated = false;
        this.initKeycloak();
    }

    initKeycloak() {
        const keycloak = new Keycloak('./keycloak.json');
        keycloak.init({
            onLoad: 'login-required'  // login-required will authenticate the client if the user is logged-in to Keycloak or display the login page if not. 
        }).then(authenticated => {
            this.keycloak = keycloak;
            this.authenticated = authenticated;
        });
    }

    async getUserInfo() {
        if(this.keycloak) {
            const userInfo = await this.keycloak.loadUserProfile();
            return {name: userInfo.name, email: userInfo.email, id: userInfo.sub};
        }
        return null;
    }

    logout() {
        if(this.keycloak)
            this.keycloak.logout();
    }
}

export default Secured;